### Easytrack python library [![pypi package](https://img.shields.io/pypi/v/python-easytrack)](https://pypi.org/project/python-easytrack/) [![Build](https://github.com/easy-track/python-easytrack/actions/workflows/build.yaml/badge.svg)](https://github.com/easy-track/python-easytrack/actions/workflows/build.yaml)

Data management library module for Easytrack backend.
